from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_check import BaseResourceCheck

# https://docs.microsoft.com/en-us/azure/templates/microsoft.web/2019-08-01/sites

class AppServiceHttps20Enabled(BaseResourceCheck):
    def __init__(self):
        name = "Ensure that 'HTTP Version' is the latest if used to run the web app"
        id = "CKV_AZURE_18"
        supported_resources = ['Microsoft.Web/sites']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if "properties" in conf:
            if "siteConfig" in conf["properties"]:
                if "http20Enabled" in conf["properties"]["siteConfig"]:
                    if str(conf["properties"]["siteConfig"]["http20Enabled"]).lower() == "true":
                        return CheckResult.PASSED
        return CheckResult.FAILED

check = AppServiceHttps20Enabled()


from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class LambdaXrayEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "X-ray tracing is enabled for Lambda"
        id = "CKV_AWS_50"
        supported_resources = ['aws_lambda_function']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "tracing_config/[0]/mode"

    def get_expected_value(self):
        return "PassThrough"

    def get_expected_values(self):
        return [self.get_expected_value(), "Active"]


check = LambdaXrayEnabled()



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories, CheckResult


class AuroraEncryption(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure all data stored in Aurora is securely encrypted at rest"
        id = "CKV_AWS_96"
        supported_resources = ['aws_rds_cluster']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        # https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.how-it-works.html#aurora-serverless.snapshots
        # If aurora serverless is used it is always encrypted
        key='engine_mode'
        if key in conf.keys():
            if conf[key] == ['serverless']:
                return CheckResult.PASSED
        return super().scan_resource_conf(conf)

    def get_inspected_key(self):
        return "storage_encrypted"


check = AuroraEncryption()



from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class RDSPubliclyAccessible(BaseResourceValueCheck):

    def __init__(self):
        name = "Ensure all data stored in the RDS bucket is not public accessible"
        id = "CKV_AWS_17"
        supported_resources = ['AWS::RDS::DBInstance']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_block_result=CheckResult.PASSED)

    def get_expected_value(self):
        return False

    def get_inspected_key(self):
        return 'Properties/PubliclyAccessible'


check = RDSPubliclyAccessible()
